Skip to contents

Runs gzip -t on a set of files to verify there is nothing wrong with them before running pump and unify. gzip must be installed and available on the system. Because this is potentially making a lot of system2 calls via purrr, it is not easy to interrupt once begun.

Usage

rc3_check_gz(fasta, regexp = "fq.gz")

Arguments

fasta

the directory to check, or a list of files directly.