Skip to contents

Sets up directory structure needed for recount3 to read data in. Note that recount3 only currently works with human or mouse, so regardless your actual organism you used, you must choose one of those two to make this work.

Usage

rc3_setup_directory(base_dir = ".", short_id = "test", organism = "human")

Arguments

base_dir

the top level directory where projects should live

short_id

the short identifier used when unifying your outputs

Value

project directory list