check gz files
rc3_check_gz.RdRuns gzip -t on a set of files to verify there is nothing wrong with
them before running pump and unify.
gzip must be installed and available on the system.
Because this is potentially making a lot of system2 calls via purrr,
it is not easy to interrupt once begun.